@@ -6,15 +6,15 @@ use warnings;
 
 BEGIN {
 	$Error::TypeTiny::AUTHORITY = 'cpan:TOBYINK';
-	$Error::TypeTiny::VERSION   = '1.011_011';
+	$Error::TypeTiny::VERSION   = '1.013_000';
 }
 
 $Error::TypeTiny::VERSION =~ tr/_//d;
 
 require Type::Tiny;
 __PACKAGE__->Type::Tiny::_install_overloads(
-	q[""]    => sub { $_[0]->to_string },
-	q[bool]  => sub { 1 },
+	q[""]   => sub { $_[0]->to_string },
+	q[bool] => sub { 1 },
 );
 
 our %CarpInternal;
@@ -63,79 +63,92 @@ $CarpInternal{$_}++ for qw(
 	Type::Utils
 );
 
-sub new
-{
-	my $class = shift;
-	my %params = (@_==1) ? %{$_[0]} : @_;
+sub new {
+	my $class  = shift;
+	my %params = ( @_ == 1 ) ? %{ $_[0] } : @_;
 	return bless \%params, $class;
 }
 
-sub throw
-{
+sub throw {
+	my $next = $_[0]->can( 'throw_cb' );
+	splice( @_, 1, 0, undef );
+	goto $next;
+}
+
+sub throw_cb {
 	my $class = shift;
+	my $callback = shift;
 	
-	my ($level, @caller, %ctxt) = 0;
-	while (do {
-		my $caller = caller $level;
-		defined $caller and $CarpInternal{$caller};
-	}) { $level++ };
-	if ( ((caller($level - 1))[1]||"") =~ /^(?:parameter validation for|exportable function) '(.+?)'$/ )
+	my ( $level, @caller, %ctxt ) = 0;
+	while (
+		do {
+			my $caller = caller $level;
+			defined $caller and $CarpInternal{$caller};
+		}
+		)
 	{
-		my ($pkg, $func) = ($1 =~ m{^(.+)::(\w+)$});
-		$level++ if caller($level) eq ($pkg||"");
+		$level++;
 	}
+	if ( ( ( caller( $level - 1 ) )[1] || "" ) =~
+		/^(?:parameter validation for|exportable function) '(.+?)'$/ )
+	{
+		my ( $pkg, $func ) = ( $1 =~ m{^(.+)::(\w+)$} );
+		$level++ if caller( $level ) eq ( $pkg || "" );
+	}
+	
 	# Moo's Method::Generate::Constructor puts an eval in the stack trace,
 	# that is useless for debugging, so show the stack frame one above.
-	$level++ if (
-		(caller($level))[1] =~ /^\(eval \d+\)$/ and
-		(caller($level))[3] eq '(eval)' # (caller())[3] is $subroutine
-	);
-	@ctxt{qw/ package file line /} = caller($level);
+	$level++
+		if (
+		( caller( $level ) )[1] =~ /^\(eval \d+\)$/
+		and ( caller( $level ) )[3] eq '(eval)'    # (caller())[3] is $subroutine
+		);
+	@ctxt{qw/ package file line /} = caller( $level );
 	
 	my $stack = undef;
-	if (our $StackTrace)
-	{
+	if ( our $StackTrace ) {
 		require Devel::StackTrace;
 		$stack = "Devel::StackTrace"->new(
 			ignore_package => [ keys %CarpInternal ],
 		);
 	}
 	
-	die(
-		our $LastError = $class->new(
-			context     => \%ctxt,
-			stack_trace => $stack,
-			@_,
-		)
+	our $LastError = $class->new(
+		context     => \%ctxt,
+		stack_trace => $stack,
+		@_,
 	);
-}
+	
+	$callback ? $callback->( $LastError ) : die( $LastError );
+} #/ sub throw
 
-sub message     { $_[0]{message} ||= $_[0]->_build_message };
-sub context     { $_[0]{context} };
-sub stack_trace { $_[0]{stack_trace} };
+sub message     { $_[0]{message} ||= $_[0]->_build_message }
+sub context     { $_[0]{context} }
+sub stack_trace { $_[0]{stack_trace} }
 
-sub to_string
-{
+sub to_string {
 	my $e = shift;
 	my $c = $e->context;
 	my $m = $e->message;
 	
-	$m =~ /\n\z/s ? $m :
-	$c            ? sprintf("%s at %s line %s.\n", $m, $c->{file}||'file?', $c->{line}||'NaN') :
-	sprintf("%s\n", $m);
-}
+	$m =~ /\n\z/s
+		? $m
+		: $c ? sprintf(
+		"%s at %s line %s.\n", $m, $c->{file} || 'file?',
+		$c->{line} || 'NaN'
+		)
+		: sprintf( "%s\n", $m );
+} #/ sub to_string
 
-sub _build_message
-{
+sub _build_message {
 	return 'An exception has occurred';
 }
 
-sub croak
-{
-	my ($fmt, @args) = @_;
+sub croak {
+	my ( $fmt, @args ) = @_;
 	@_ = (
 		__PACKAGE__,
-		message => sprintf($fmt, @args),
+		message => sprintf( $fmt, @args ),
 	);
 	goto \&throw;
 }
@@ -192,6 +205,13 @@ Constructs an exception and passes it to C<die>.
 
 Automatically populates C<context> and C<stack_trace> if appropriate.
 
+=item C<< throw_cb($callback, %attributes) >>
+
+Constructs an exception and passes it to C<< $callback >> which should
+be a coderef; if undef, uses C<die>.
+
+Automatically populates C<context> and C<stack_trace> if appropriate.
+
 =back
 
 =head2 Attributes
@@ -277,7 +297,7 @@ package variable may save your bacon.)
 =head1 BUGS
 
 Please report any bugs to
-L<http://rt.cpan.org/Dist/Display.html?Queue=Type-Tiny>.
+L<https://github.com/tobyink/p5-type-tiny/issues>.
 
 =head1 SEE ALSO
 
@@ -292,7 +312,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2020 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2022 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -302,4 +322,3 @@ the same terms as the Perl 5 programming language system itself.
 THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-
